@@ -111,7 +111,7 @@ def check_api():
     keys = svars.keys()
 
     for key in keys:
-        if not 'item' in key and not 'islooping' in key:
+        if not 'item' in key and not 'playlist' in key.lower():
             if isinstance(svars[key], bool):
                 if not 'Player' in key and bool(svars[key]):
                     news_categories.append(key)
